==> wrogue-0.7.4.tar.bz2: wrogue-0.7.4/src/help.c <==
/*
 * Copyright (C) 2002-2007 The Warp Rogue Team
 * Part of the Warp Rogue Project
 *
 * This software is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License.
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY.
 *
 * See the license.txt file for more details.
 */

/*
 * Module Name: Help
 * Description: -
 */

#define Uses_Ui
#define Uses_DataFile
#define Uses_Career
#include "mheader.h"

#include "help.h"



typedef struct help_file_data_struct	HELP_FILE_DATA;


/*
 * help file data structure
 */
struct help_file_data_struct {

	/* title of the help file */
	char *		title;

	/* file name of the help file */
	const char *	file_name;

};



static void		additional_information_screen(void);

static void		show_career_list(void);



/*
 * help file data
 */
static const HELP_FILE_DATA	HelpFile[MAX_HELP_FILES] = {

	{"Stats",			FILE_HELP_STATS},
	{"Perks",			FILE_HELP_PERKS},
	{"Status",			FILE_HELP_STATUS},
	{"Parties",			FILE_HELP_PARTIES},
	{"Advancement",			FILE_HELP_ADVANCEMENT},
	{"Careers",			FILE_HELP_CAREERS},
	{"Timing",			FILE_HELP_TIMING},
	{"Movement",			FILE_HELP_MOVEMENT},
	{"Combat",			FILE_HELP_COMBAT},
	{"Evocation",			FILE_HELP_EVOCATION},
	{"Psychic Powers",		FILE_HELP_PSYCHIC_POWERS},
	{"Tactical Commands",		FILE_HELP_TACTICS},
	{"Objects",			FILE_HELP_OBJECTS},
	{"Terrain",			FILE_HELP_TERRAIN},
	{"Macros",			FILE_HELP_MACROS},
	{"Hints",			FILE_HELP_HINTS}

};



/*
 * the help screen
 */
void help_screen(void)
{

	command_bar_set(2, CM_ADDITIONAL_INFORMATION, CM_EXIT);

	render_help_screen();

	update_screen();

	if (command_bar_get_command() == CM_EXIT) {

		return;
	}

	additional_information_screen();
}



/*
 * the additional information screen
 */
static void additional_information_screen(void)
{
	LIST *items;
	MENU *menu;
	FILE_COUNTER i;

	items = list_new();

	for (i = 0; i < MAX_HELP_FILES; i++) {

		list_add(items, HelpFile[i].title);
	}

	menu = menu_create(items);

	while (true) {
		command_bar_set(4, CM_UP, CM_DOWN, CM_OK, CM_EXIT);

		render_additional_information_screen();

		additional_information_menu(menu);

		if (menu->entered_command == CM_EXIT) {

			break;
		}
		
		/* hack */
		if (HelpFile[menu->highlighted].file_name == NULL) {
			
			show_career_list();

			continue;
		}

		show_text_file(
			HelpFile[menu->highlighted].title,
			HelpFile[menu->highlighted].file_name,
			false
		);
	}

	menu_destroy(menu);
}



/*
 * shows a list of all careers
 */
static void show_career_list(void)
{
	MENU *menu;
	LIST *items;
	N_CAREERS n_careers;
	CAREER_COUNTER i;

	n_careers = get_n_careers();
	items = list_new();

	for (i = 0; i < n_careers; i++) {
		CAREER *career;

		career = get_career_pointer(i);

		list_add(items, (void *)career->name);
	}

	menu = menu_create(items);

	do {

		command_bar_set(5, CM_UP, CM_DOWN, CM_INFO, CM_OK,
			CM_EXIT
		);

		render_show_career_list_screen();
		update_screen();

		show_career_list_menu(menu);

		if (menu->entered_command == CM_INFO) {
			CAREER_INDEX career_index;
			const char *career_name;
			
			career_name = (const char *)list_data_at(menu->items,
				menu->highlighted
			);

			career_index = name_to_career_index(career_name);

			career_screen(get_career_pointer(career_index));
		}

	} while (menu->entered_command != CM_EXIT);
	
	menu_destroy(menu);
}

==> wrogue-0.7.5.tar.bz2: wrogue-0.7.5/src/help.c <==
/*
 * Copyright (C) 2002-2007 The Warp Rogue Team
 * Part of the Warp Rogue Project
 *
 * This software is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License.
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY.
 *
 * See the license.txt file for more details.
 */

/*
 * Module Name: Help
 * Description: -
 */

#define Uses_Ui
#define Uses_DataFile
#define Uses_Career
#define Uses_Perks
#include "mheader.h"

#include "help.h"


/*
 * help files
 */
#define MAX_HELP_FILES			16
#define FILE_HELP_STATS			"stats.txt"
#define FILE_HELP_PERKS			NULL
#define FILE_HELP_STATUS		"status.txt"
#define FILE_HELP_OBJECTS		"objects.txt"
#define FILE_HELP_TERRAIN		"terrain.txt"
#define FILE_HELP_PARTIES		"parties.txt"
#define FILE_HELP_ADVANCEMENT		"advance.txt"
#define FILE_HELP_CAREERS		NULL
#define FILE_HELP_TIMING		"timing.txt"
#define FILE_HELP_MOVEMENT		"movement.txt"
#define FILE_HELP_COMBAT		"combat.txt"
#define FILE_HELP_EVOCATION		"evoke.txt"
#define FILE_HELP_PSYCHIC_POWERS	"powers.txt"
#define FILE_HELP_MACROS		"macro.txt"
#define FILE_HELP_HINTS			"hints.txt"
#define FILE_HELP_TACTICS		"tactics.txt"



/*
 * help file data structure
 */
typedef struct {

	/* title of the help file */
	char *		title;

	/* file name of the help file */
	const char *	file_name;

} HELP_FILE_DATA;



static void		additional_information_screen(void);

static void		show_career_list(void);
static void		show_perk_list(void);



/*
 * help file data
 */
static const HELP_FILE_DATA	HelpFile[MAX_HELP_FILES] = {

	{"Stats",			FILE_HELP_STATS},
	{"Perks",			FILE_HELP_PERKS},
	{"Status",			FILE_HELP_STATUS},
	{"Parties",			FILE_HELP_PARTIES},
	{"Advancement",			FILE_HELP_ADVANCEMENT},
	{"Careers",			FILE_HELP_CAREERS},
	{"Timing",			FILE_HELP_TIMING},
	{"Movement",			FILE_HELP_MOVEMENT},
	{"Combat",			FILE_HELP_COMBAT},
	{"Evocation",			FILE_HELP_EVOCATION},
	{"Psychic Powers",		FILE_HELP_PSYCHIC_POWERS},
	{"Tactical Commands",		FILE_HELP_TACTICS},
	{"Objects",			FILE_HELP_OBJECTS},
	{"Terrain",			FILE_HELP_TERRAIN},
	{"Macros",			FILE_HELP_MACROS},
	{"Hints",			FILE_HELP_HINTS}

};



/*
 * the help screen
 */
void help_screen(void)
{

	command_bar_set(2, CM_ADDITIONAL_INFORMATION, CM_EXIT);

	render_help_screen();

	update_screen();

	if (command_bar_get_command() == CM_EXIT) {

		return;
	}

	additional_information_screen();
}



/*
 * the additional information screen
 */
static void additional_information_screen(void)
{
	LIST *items;
	MENU *menu;
	FILE_COUNTER i;

	items = list_new();

	for (i = 0; i < MAX_HELP_FILES; i++) {

		list_add(items, HelpFile[i].title);
	}

	menu = menu_create(items);

	while (true) {
		command_bar_set(4, CM_UP, CM_DOWN, CM_OK, CM_EXIT);

		render_additional_information_screen();

		additional_information_menu(menu);

		if (menu->entered_command == CM_EXIT) {

			break;
		}
		
		/* hack */
		if (HelpFile[menu->highlighted].file_name == NULL) {
			
			if (menu->highlighted == 1) {
				
				show_perk_list();
				
			} else {
				
				show_career_list();
			}

			continue;
		}

		show_text_file(
			HelpFile[menu->highlighted].title,
			HelpFile[menu->highlighted].file_name,
			false
		);
	}

	menu_destroy(menu);
}



/*
 * shows a list of all careers
 */
static void show_career_list(void)
{
	MENU *menu;
	LIST *items;
	N_CAREERS n_careers;
	CAREER_INDEX i;

	n_careers = get_n_careers();
	items = list_new();

	for (i = 0; i < n_careers; i++) {
		CAREER *career;

		career = get_career_pointer(i);

		list_add(items, (void *)career->name);
	}

	menu = menu_create(items);

	do {

		command_bar_set(4, CM_UP, CM_DOWN, CM_INFO, CM_EXIT);

		render_show_career_list_screen();
		update_screen();

		show_career_list_menu(menu);

		if (menu->entered_command == CM_INFO) {
			CAREER_INDEX career_index;
			const char *career_name;
			
			career_name = (const char *)list_data_at(menu->items,
				menu->highlighted
			);

			career_index = name_to_career_index(career_name);

			career_screen(get_career_pointer(career_index));
		}

	} while (menu->entered_command != CM_EXIT);
	
	menu_destroy(menu);
}



/*
 * shows a list of all perks
 */
static void show_perk_list(void)
{
	MENU *menu;
	LIST *items;
	PERK i;

	items = list_new();

	for (i = 0; i < MAX_PERKS; i++) {

		list_add(items, (void *)perk_name(i));
	}

	menu = menu_create(items);

	do {

		command_bar_set(4, CM_UP, CM_DOWN, CM_INFO, CM_EXIT);

		render_show_perk_list_screen();
		update_screen();

		show_perk_list_menu(menu);

		if (menu->entered_command == CM_INFO) {
			const char *name;
			PERK perk;
			
			name = (const char *)list_data_at(menu->items,
				menu->highlighted
			);

			perk = name_to_perk(name);

			perk_screen(perk);
		}

	} while (menu->entered_command != CM_EXIT);
	
	menu_destroy(menu);
}
